searchData={"items":[{"type":"module","title":"Codeowners","doc":"A pure Elixir parser for the GitHub CODEOWNERS [specification](https://docs.github.com/en/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners).\n\n```elixir\n> Codeowners.load(\".github/CODEOWNERS\") |> Codeowners.rule_for_path(\"docs/setup.md\")\n%Codeowners.Rule{\n  pattern: \"docs/*\",\n  regex: ~r/docs/[^/]*z/,\n  owners: [\"docs@example.com\"]\n}\n```","ref":"Codeowners.html"},{"type":"function","title":"Codeowners.build/2","doc":"Builds a `Codeowners` struct from a string containing CODEOWNERS rules.\n\nParses each line generating a list of `Codeowners.Rule`.\n\nFor most use cases it makes sense to use `load/2`, which in turn calls `build/2`","ref":"Codeowners.html#build/2"},{"type":"function","title":"Codeowners.load/2","doc":"Loads a CODEOWNERS file from the given path, returning a `Codeowners` struct.\n\n`load/2` calls `build/2` to process the contained ownership rules.","ref":"Codeowners.html#load/2"},{"type":"function","title":"Codeowners.rule_for_module/2","doc":"Given a `Codeowners` struct and an Elixir module, return the matching rule or empty rule.\n\n`rule_for_module/2` calls `rule_for_path/2`.","ref":"Codeowners.html#rule_for_module/2"},{"type":"function","title":"Codeowners.rule_for_path/2","doc":"Given a `Codeowners` struct and path, return the matching rule or empty rule.\n\nSearches in reverse to return the last match.\nHandles full paths by removing the root directory before matching.","ref":"Codeowners.html#rule_for_path/2"},{"type":"type","title":"Codeowners.t/0","doc":"","ref":"Codeowners.html#t:t/0"},{"type":"module","title":"Codeowners.Rule","doc":"Contains types and functions related to individual CODEOWNERS rules.","ref":"Codeowners.Rule.html"},{"type":"function","title":"Codeowners.Rule.build/1","doc":"Build a `Codeowners.Rule` for the given CODEOWNERS line.","ref":"Codeowners.Rule.html#build/1"},{"type":"function","title":"Codeowners.Rule.regex/1","doc":"Compile a `Regex` for the given pattern string.","ref":"Codeowners.Rule.html#regex/1"},{"type":"type","title":"Codeowners.Rule.t/0","doc":"","ref":"Codeowners.Rule.html#t:t/0"},{"type":"task","title":"mix codeowners","doc":"List owners for files based on CODEOWNERS.\n\n    mix codeowners lib/","ref":"Mix.Tasks.Codeowners.html"},{"type":"extras","title":"Codeowners","doc":"# Codeowners\n\nA pure Elixir parser for the GitHub CODEOWNERS [specification](https://docs.github.com/en/repositories/managing-your-repositorys-settings-and-features/customizing-your-repository/about-code-owners).","ref":"readme.html"},{"type":"extras","title":"Installation - Codeowners","doc":"The package can be installed by adding `codeowners` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:codeowners, \"~> 0.2.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic usage - Codeowners","doc":"```elixir\n> codeowners = Codeowners.load(\".github/CODEOWNERS\")\n%Codeowners{\n  path: \"/Users/me/project/.github/CODEOWNERS\",\n  root: \"/Users/me/project\",\n  rules: [\n    %Codeowners.Rule{\n      pattern: \"*\",\n      regex: ~r/[^\\/]*/,\n      owners: [\"@global-owner1\", \"@global-owner2\"]\n    },\n    %Codeowners.Rule{\n      pattern: \"*.js\",\n      regex: ~r/[^\\/]*\\.js/,\n      owners: [\"@js-owner\"]\n    },\n    ...\n  ]\n}\n\n> matching_rule = Codeowners.rule_for_path(codeowners, \"docs/setup.md\")\n%Codeowners.Rule{\n  pattern: \"docs/*\",\n  regex: ~r/docs\\/[^\\/]*\\z/,\n  owners: [\"docs@example.com\"]\n}\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"Mix task - Codeowners","doc":"```sh\n~/my_project/:$ mix codeowners README.md\nUsing .github/CODEOWNERS\nREADME.md    @my-team\n```","ref":"readme.html#mix-task"},{"type":"extras","title":"License - Codeowners","doc":"MIT License - see the [LICENSE](https://github.com/reid-rigo/codeowners/blob/main/LICENSE) file.","ref":"readme.html#license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}